# -*- coding: utf-8 -*-

__author__ = 'Fabio Caccamo'
__copyright__ = 'Copyright (c) 2019 Fabio Caccamo'
__description__ = 'python-benedict is the Python dictionary for humans dealing with evil data.'
__license__ = 'MIT'
__title__ = 'benedict'
__version__ = '0.2.0'